callback property
Optional callback with stickiness value. If you think you need this, then you might want to
consider using itemBuilder instead.
Implementation
final RenderItemCallback? callback;
Optional callback with stickiness value. If you think you need this, then you might want to
consider using itemBuilder instead.
final RenderItemCallback? callback;